@@ -1,30 +1,12 @@
-# -*- coding: UTF-8 -*-
-##############################################################################
-#
-#    OdooRPC
-#    Copyright (C) 2014 Sébastien Alix.
-#
-#    This program is free software: you can redistribute it and/or modify
-#    it under the terms of the GNU Lesser General Public License as published
-#    by the Free Software Foundation, either version 3 of the License, or
-#    (at your option) any later version.
-#
-#    This program is distributed in the hope that it will be useful,
-#    but WITHOUT ANY WARRANTY; without even the implied warranty of
-#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#    GNU Lesser General Public License for more details.
-#
-#    You should have received a copy of the GNU Lesser General Public License
-#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#
-##############################################################################
+# -*- coding: utf-8 -*-
+# Copyright 2014 Sébastien Alix
+# License LGPL-3.0 or later (http://www.gnu.org/licenses/lgpl)
 """This module contains the ``ODOO`` class which is the entry point to manage
 an `Odoo` server.
 """
-from odoorpc import rpc, error, tools
-from odoorpc.env import Environment
-from odoorpc import session
+from odoorpc import error, rpc, session, tools
 from odoorpc.db import DB
+from odoorpc.env import Environment
 from odoorpc.report import Report
 
 
@@ -75,21 +57,30 @@ class ODOO(object):
     :raise: `urllib.error.URLError` (connection error)
     """
 
-    def __init__(self, host='localhost', protocol='jsonrpc',
-                 port=8069, timeout=120, version=None, opener=None):
+    def __init__(
+        self,
+        host='localhost',
+        protocol='jsonrpc',
+        port=8069,
+        timeout=120,
+        version=None,
+        opener=None,
+    ):
         if protocol not in ['jsonrpc', 'jsonrpc+ssl']:
-            txt = ("The protocol '{0}' is not supported by the ODOO class. "
-                   "Please choose a protocol among these ones: {1}")
+            txt = (
+                "The protocol '{0}' is not supported by the ODOO class. "
+                "Please choose a protocol among these ones: {1}"
+            )
             txt = txt.format(protocol, ['jsonrpc', 'jsonrpc+ssl'])
             raise ValueError(txt)
         try:
             port = int(port)
-        except ValueError:
+        except (ValueError, TypeError):
             raise ValueError("The port must be an integer")
         try:
             if timeout is not None:
                 timeout = float(timeout)
-        except ValueError:
+        except (ValueError, TypeError):
             raise ValueError("The timeout must be a float")
         self._host = host
         self._port = port
@@ -102,15 +93,15 @@ class ODOO(object):
         # Instanciate the server connector
         try:
             self._connector = rpc.PROTOCOLS[protocol](
-                self._host, self._port, timeout, version, opener=opener)
+                self._host, self._port, timeout, version, opener=opener
+            )
         except rpc.error.ConnectorError as exc:
             raise error.InternalError(exc.message)
         # Dictionary of configuration options
         self._config = tools.Config(
             self,
-            {'auto_commit': True,
-             'auto_context': True,
-             'timeout': timeout})
+            {'auto_commit': True, 'auto_context': True, 'timeout': timeout},
+        )
 
     @property
     def config(self):
@@ -185,12 +176,12 @@ class ODOO(object):
         """
         return self._report
 
-    host = property(lambda self: self._host,
-                    doc="Hostname of IP address of the the server.")
-    port = property(lambda self: self._port,
-                    doc="The port used.")
-    protocol = property(lambda self: self._protocol,
-                        doc="The protocol used.")
+    host = property(
+        lambda self: self._host,
+        doc="Hostname of IP address of the the server.",
+    )
+    port = property(lambda self: self._port, doc="The port used.")
+    protocol = property(lambda self: self._protocol, doc="The protocol used.")
 
     @property
     def env(self):
@@ -206,7 +197,6 @@ class ODOO(object):
         self._check_logged_user()
         return self._env
 
-
     def json(self, url, params):
         """Low level method to execute JSON queries.
         It basically performs a request and raises an
@@ -281,8 +271,8 @@ class ODOO(object):
         data = self._connector.proxy_json(url, params)
         if data.get('error'):
             raise error.RPCError(
-                data['error']['data']['message'],
-                data['error'])
+                data['error']['data']['message'], data['error']
+            )
         return data
 
     def http(self, url, data=None, headers=None):
@@ -352,7 +342,8 @@ class ODOO(object):
         # Get the user's ID and generate the corresponding user record
         data = self.json(
             '/web/session/authenticate',
-            {'db': db, 'login': login, 'password': password})
+            {'db': db, 'login': login, 'password': password},
+        )
         uid = data['result']['uid']
         if uid:
             context = data['result']['user_context']
@@ -427,14 +418,18 @@ class ODOO(object):
         """
         self._check_logged_user()
         # Execute the query
-        args_to_send = [self.env.db, self.env.uid, self._password,
-                        model, method]
+        args_to_send = [
+            self.env.db,
+            self.env.uid,
+            self._password,
+            model,
+            method,
+        ]
         args_to_send.extend(args)
         data = self.json(
             '/jsonrpc',
-            {'service': 'object',
-             'method': 'execute',
-             'args': args_to_send})
+            {'service': 'object', 'method': 'execute', 'args': args_to_send},
+        )
         return data.get('result')
 
     def execute_kw(self, model, method, args=None, kwargs=None):
@@ -476,14 +471,22 @@ class ODOO(object):
         # Execute the query
         args = args or []
         kwargs = kwargs or {}
-        args_to_send = [self.env.db, self.env.uid, self._password,
-                        model, method]
+        args_to_send = [
+            self.env.db,
+            self.env.uid,
+            self._password,
+            model,
+            method,
+        ]
         args_to_send.extend([args, kwargs])
         data = self.json(
             '/jsonrpc',
-            {'service': 'object',
-             'method': 'execute_kw',
-             'args': args_to_send})
+            {
+                'service': 'object',
+                'method': 'execute_kw',
+                'args': args_to_send,
+            },
+        )
         return data.get('result')
 
     def exec_workflow(self, model, record_id, signal):
@@ -504,16 +507,26 @@ class ODOO(object):
         """
         if tools.v(self.version)[0] >= 11:
             raise DeprecationWarning(
-                u"Workflows have been removed in Odoo >= 11.0")
+                u"Workflows have been removed in Odoo >= 11.0"
+            )
         self._check_logged_user()
         # Execute the workflow query
-        args_to_send = [self.env.db, self.env.uid, self._password,
-                        model, signal, record_id]
+        args_to_send = [
+            self.env.db,
+            self.env.uid,
+            self._password,
+            model,
+            signal,
+            record_id,
+        ]
         data = self.json(
             '/jsonrpc',
-            {'service': 'object',
-             'method': 'exec_workflow',
-             'args': args_to_send})
+            {
+                'service': 'object',
+                'method': 'exec_workflow',
+                'args': args_to_send,
+            },
+        )
         return data.get('result')
 
     # ---------------------- #
@@ -584,8 +597,8 @@ class ODOO(object):
         data = session.get(name, rc_file)
         if data.get('type') != cls.__name__:
             raise error.InternalError(
-                "'{0}' session is not of type '{1}'".format(
-                    name, cls.__name__))
+                "'{}' session is not of type '{}'".format(name, cls.__name__)
+            )
         odoo = cls(
             host=data['host'],
             protocol=data['protocol'],
@@ -593,7 +606,8 @@ class ODOO(object):
             timeout=data['timeout'],
         )
         odoo.login(
-            db=data['database'], login=data['user'], password=data['passwd'])
+            db=data['database'], login=data['user'], password=data['passwd']
+        )
         return odoo
 
     @classmethod
@@ -621,9 +635,12 @@ class ODOO(object):
         :raise: `FileNotFoundError`
         """
         sessions = session.get_all(rc_file)
-        return [name for name in sessions
-                if sessions[name].get('type') == cls.__name__]
-        #return session.list(rc_file)
+        return [
+            name
+            for name in sessions
+            if sessions[name].get('type') == cls.__name__
+        ]
+        # return session.list(rc_file)
 
     @classmethod
     def remove(cls, name, rc_file='~/.odoorpcrc'):
@@ -650,8 +667,6 @@ class ODOO(object):
         data = session.get(name, rc_file)
         if data.get('type') != cls.__name__:
             raise error.InternalError(
-                "'{0}' session is not of type '{1}'".format(
-                    name, cls.__name__))
+                "'{}' session is not of type '{}'".format(name, cls.__name__)
+            )
         return session.remove(name, rc_file)
-
-# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:
