@@ -1,30 +1,13 @@
-# -*- coding: UTF-8 -*-
-##############################################################################
-#
-#    OdooRPC
-#    Copyright (C) 2014 Sébastien Alix.
-#
-#    This program is free software: you can redistribute it and/or modify
-#    it under the terms of the GNU Lesser General Public License as published
-#    by the Free Software Foundation, either version 3 of the License, or
-#    (at your option) any later version.
-#
-#    This program is distributed in the hope that it will be useful,
-#    but WITHOUT ANY WARRANTY; without even the implied warranty of
-#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#    GNU Lesser General Public License for more details.
-#
-#    You should have received a copy of the GNU Lesser General Public License
-#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#
-##############################################################################
+# -*- coding: utf-8 -*-
+# Copyright 2014 Sébastien Alix
+# License LGPL-3.0 or later (http://www.gnu.org/licenses/lgpl)
 """This module provide the :class:`Report` class to list available reports and
 to generate/download them.
 """
 import base64
 import io
 
-from odoorpc.tools import v, get_encodings
+from odoorpc.tools import get_encodings, v
 
 
 def encode2bytes(data):
@@ -62,6 +45,7 @@ class Report(object):
         >>> odoo.report
         <odoorpc.report.Report object at ...>
     """
+
     def __init__(self, odoo):
         self._odoo = odoo
 
@@ -130,7 +114,14 @@ class Report(object):
         if v(self._odoo.version)[0] >= 11:
             IrReport = self._odoo.env['ir.actions.report']
             report = IrReport.browse(report_id)
-            response = report.with_context(context).render(ids, data=datas)
+            if v(self._odoo.version)[0] >= 14:
+                # Need a CSRF token to print reports on Odoo >= 14
+                raise NotImplementedError
+                # response = report.with_context(context)._render(
+                #     ids, data=datas
+                # )
+            else:
+                response = report.with_context(context).render(ids, data=datas)
             content = response[0]
             # On the server the result is a bytes string,
             # but the RPC layer of Odoo returns it as a unicode string,
@@ -139,14 +130,23 @@ class Report(object):
             return io.BytesIO(result)
         # Odoo < 11.0
         else:
-            args_to_send = [self._odoo.env.db,
-                            self._odoo.env.uid, self._odoo._password,
-                            name, ids, datas, context]
+            args_to_send = [
+                self._odoo.env.db,
+                self._odoo.env.uid,
+                self._odoo._password,
+                name,
+                ids,
+                datas,
+                context,
+            ]
             data = self._odoo.json(
                 '/jsonrpc',
-                {'service': 'report',
-                 'method': 'render_report',
-                 'args': args_to_send})
+                {
+                    'service': 'report',
+                    'method': 'render_report',
+                    'args': args_to_send,
+                },
+            )
             if 'result' not in data and not data['result'].get('result'):
                 raise ValueError("Received invalid data.")
             # Encode to bytes forced to be compatible with Python 3.2
@@ -162,7 +162,11 @@ class Report(object):
         .. doctest::
             :options: +SKIP
 
-            >>> odoo.report.list()['account.invoice']
+            >>> from odoorpc.tools import v
+            >>> inv_model = 'account.move'
+            >>> if v(VERSION) < v('13.0'):
+            ...     inv_model = 'account.invoice'
+            >>> odoo.report.list()[inv_model]
             [{'name': u'Duplicates',
               'report_name': u'account.account_invoice_report_duplicate_main',
               'report_type': u'qweb-pdf'},
@@ -173,9 +177,13 @@ class Report(object):
         .. doctest::
             :hide:
 
+            >>> from odoorpc.tools import v
+            >>> inv_model = 'account.move'
+            >>> if v(VERSION) < v('13.0'):
+            ...     inv_model = 'account.invoice'
             >>> from pprint import pprint as pp
             >>> any(data['report_name'] == 'account.report_invoice'
-            ...     for data in odoo.report.list()['account.invoice'])
+            ...     for data in odoo.report.list()[inv_model])
             True
 
         *Python 2:*
@@ -194,7 +202,8 @@ class Report(object):
         IrReport = self._odoo.env[report_model]
         report_ids = IrReport.search([])
         reports = IrReport.read(
-            report_ids, ['name', 'model', 'report_name', 'report_type'])
+            report_ids, ['name', 'model', 'report_name', 'report_type']
+        )
         result = {}
         for report in reports:
             model = report.pop('model')
@@ -203,5 +212,3 @@ class Report(object):
                 result[model] = []
             result[model].append(report)
         return result
-
-# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:
