@@ -1,54 +1,41 @@
 # -*- coding: utf-8 -*-
-##############################################################################
-#
-#    OdooRPC
-#    Copyright (C) 2014 Sébastien Alix.
-#
-#    This program is free software: you can redistribute it and/or modify
-#    it under the terms of the GNU Lesser General Public License as published
-#    by the Free Software Foundation, either version 3 of the License, or
-#    (at your option) any later version.
-#
-#    This program is distributed in the hope that it will be useful,
-#    but WITHOUT ANY WARRANTY; without even the implied warranty of
-#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#    GNU Lesser General Public License for more details.
-#
-#    You should have received a copy of the GNU Lesser General Public License
-#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#
-##############################################################################
+# Copyright 2014 Sébastien Alix
+# License LGPL-3.0 or later (http://www.gnu.org/licenses/lgpl)
 """Provides the :class:`ProxyJSON` class for JSON-RPC requests."""
 import copy
 import json
 import logging
 import random
 import sys
+
 # Python 2
 if sys.version_info[0] < 3:
-    from urllib2 import build_opener, HTTPCookieProcessor, Request
     from cookielib import CookieJar
+    from urllib2 import HTTPCookieProcessor, Request, build_opener
 
     def encode_data(data):
         return data
 
     def decode_data(data):
         return data
+
+
 # Python >= 3
 else:
-    from urllib.request import build_opener, HTTPCookieProcessor, Request
-    from http.cookiejar import CookieJar
     import io
+    from http.cookiejar import CookieJar
+    from urllib.request import HTTPCookieProcessor, Request, build_opener
 
     def encode_data(data):
         try:
             return bytes(data, 'utf-8')
-        except:
+        except:  # noqa: E722
             return bytes(data)
 
     def decode_data(data):
         return io.StringIO(data.read().decode('utf-8'))
 
+
 LOG_HIDDEN_JSON_PARAMS = ['password']
 LOG_JSON_SEND_MSG = u"(JSON,send) %(url)s %(data)s"
 LOG_JSON_RECV_MSG = u"(JSON,recv) %(url)s %(data)s => %(result)s"
@@ -73,9 +60,11 @@ def get_json_log_data(data):
 
 class Proxy(object):
     """Base class to implement a proxy to perform requests."""
+
     def __init__(self, host, port, timeout=120, ssl=False, opener=None):
         self._root_url = "{http}{host}:{port}".format(
-            http=(ssl and "https://" or "http://"), host=host, port=port)
+            http=(ssl and "https://" or "http://"), host=host, port=port
+        )
         self._timeout = timeout
         self._builder = URLBuilder(self)
         self._opener = opener
@@ -97,8 +86,10 @@ class ProxyJSON(Proxy):
     """The :class:`ProxyJSON` class provides a dynamic access
     to all JSON methods.
     """
-    def __init__(self, host, port, timeout=120, ssl=False, opener=None,
-                 deserialize=True):
+
+    def __init__(
+        self, host, port, timeout=120, ssl=False, opener=None, deserialize=True
+    ):
         Proxy.__init__(self, host, port, timeout, ssl, opener)
         self._deserialize = deserialize
 
@@ -115,9 +106,7 @@ class ProxyJSON(Proxy):
             url = url[1:]
         full_url = self._get_full_url(url)
         log_data = get_json_log_data(data)
-        logger.debug(
-            LOG_JSON_SEND_MSG,
-            {'url': full_url, 'data': log_data})
+        logger.debug(LOG_JSON_SEND_MSG, {'url': full_url, 'data': log_data})
         data_json = json.dumps(data)
         request = Request(url=full_url, data=encode_data(data_json))
         request.add_header('Content-Type', 'application/json')
@@ -127,7 +116,8 @@ class ProxyJSON(Proxy):
         result = json.load(decode_data(response))
         logger.debug(
             LOG_JSON_RECV_MSG,
-            {'url': full_url, 'data': log_data, 'result': result})
+            {'url': full_url, 'data': log_data, 'result': result},
+        )
         return result
 
 
@@ -135,16 +125,16 @@ class ProxyHTTP(Proxy):
     """The :class:`ProxyHTTP` class provides a dynamic access
     to all HTTP methods.
     """
+
     def __call__(self, url, data=None, headers=None):
         if url.startswith('/'):
             url = url[1:]
         full_url = self._get_full_url(url)
         logger.debug(
             LOG_HTTP_SEND_MSG,
-            {'url': full_url, 'data': data and u" (%s)" % data or u""})
-        kwargs = {
-            'url': full_url,
-        }
+            {'url': full_url, 'data': data and u" (%s)" % data or u""},
+        )
+        kwargs = {'url': full_url}
         if data:
             kwargs['data'] = encode_data(data)
         request = Request(**kwargs)
@@ -155,9 +145,12 @@ class ProxyHTTP(Proxy):
         response = self._opener.open(request, timeout=self._timeout)
         logger.debug(
             LOG_HTTP_RECV_MSG,
-            {'url': full_url,
-             'data': data and u" (%s)" % data or u"",
-             'result': response})
+            {
+                'url': full_url,
+                'data': data and u" (%s)" % data or u"",
+                'result': response,
+            },
+        )
         return response
 
 
@@ -165,6 +158,7 @@ class URLBuilder(object):
     """Auto-builds an URL while getting its attributes.
     Used by the :class:`ProxyJSON` and :class:`ProxyHTTP` classes.
     """
+
     def __init__(self, rpc, url=None):
         self._rpc = rpc
         self._url = url
@@ -185,5 +179,3 @@ class URLBuilder(object):
 
     def __str__(self):
         return self._url
-
-# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:
