@@ -1,20 +1,24 @@
-# -*- coding: UTF-8 -*-
-try:
-    import unittest2 as unittest
-except:
-    import unittest
-
+# -*- coding: utf-8 -*-
 import os
+import time
 
 import odoorpc
 
+try:
+    import unittest2 as unittest
+except ImportError:
+    import unittest
+
+from odoorpc.tools import v
+
 
 class BaseTestCase(unittest.TestCase):
     """Instanciates an ``odoorpc.ODOO`` object, nothing more."""
+
     def setUp(self):
         try:
             port = int(os.environ.get('ORPC_TEST_PORT', 8069))
-        except ValueError:
+        except (ValueError, TypeError):
             raise ValueError("The port must be an integer")
         self.env = {
             'protocol': os.environ.get('ORPC_TEST_PROTOCOL', 'jsonrpc'),
@@ -27,30 +31,37 @@ class BaseTestCase(unittest.TestCase):
             'super_pwd': os.environ.get('ORPC_TEST_SUPER_PWD', 'admin'),
         }
         self.odoo = odoorpc.ODOO(
-            self.env['host'], protocol=self.env['protocol'],
-            port=self.env['port'], version=self.env['version'])
+            self.env['host'],
+            protocol=self.env['protocol'],
+            port=self.env['port'],
+            version=self.env['version'],
+        )
         # Create the database
         default_timeout = self.odoo.config['timeout']
         self.odoo.config['timeout'] = 600
         if self.env['db'] not in self.odoo.db.list():
-            self.odoo.db.create(
-                self.env['super_pwd'], self.env['db'], True)
+            self.odoo.db.create(self.env['super_pwd'], self.env['db'], True)
         self.odoo.config['timeout'] = default_timeout
 
 
 class LoginTestCase(BaseTestCase):
     """Instanciates an ``odoorpc.ODOO`` object and perform the user login."""
+
     def setUp(self):
         BaseTestCase.setUp(self)
         default_timeout = self.odoo.config['timeout']
         self.odoo.login(self.env['db'], self.env['user'], self.env['pwd'])
+        self._disable_cron_jobs()
         # Install 'sale' + 'crm_claim' on Odoo < 10.0,
-        # and 'sale' + 'subscription' on Odoo >= 10.0
+        # 'sale' + 'subscription' on Odoo == 10.0
+        # and only 'sale' on > 10.0
         self.odoo.config['timeout'] = 600
         module_obj = self.odoo.env['ir.module.module']
         modules = ['sale', 'crm_claim']
-        if self.odoo.version == '10.0':
+        if v(self.odoo.version)[0] == 10:
             modules = ['sale', 'subscription']
+        elif v(self.odoo.version)[0] >= 11:
+            modules = ['sale']
         module_ids = module_obj.search([('name', 'in', modules)])
         module_obj.button_immediate_install(module_ids)
         self.odoo.config['timeout'] = default_timeout
@@ -59,4 +70,18 @@ class LoginTestCase(BaseTestCase):
         self.user = self.odoo.env.user
         self.user_obj = self.odoo.env['res.users']
 
-# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:
+    def _disable_cron_jobs(self):
+        # Disable cron jobs so installation of modules in tests doesn't
+        # trigger "Odoo is currently processing a scheduled action." error.
+        cron_disabled = False
+        attempts = 0
+        while not cron_disabled and attempts < 20:
+            try:
+                cron_model = self.odoo.env["ir.cron"]
+                cron_ids = cron_model.search([])
+                cron_model.write(cron_ids, {"active": False})
+            except odoorpc.error.RPCError:
+                time.sleep(1)  # Let's wait a bit before trying again
+                attempts += 1
+            else:
+                cron_disabled = True
