@@ -1,4 +1,4 @@
-# -*- coding: UTF-8 -*-
+# -*- coding: utf-8 -*-
 
 import sys
 
@@ -6,16 +6,19 @@ from odoorpc.tests import LoginTestCase
 
 # Python 2
 if sys.version_info.major < 3:
+
     def is_string(arg):
-        return isinstance(arg, str) or isinstance(arg, unicode)
+        return isinstance(arg, str) or isinstance(arg, unicode)  # noqa: F821
+
+
 # Python >= 3
 else:
+
     def is_string(arg):
         return isinstance(arg, str)
 
 
 class TestFieldText(LoginTestCase):
-
     def test_field_text_read(self):
         # Test empty field
         self.assertFalse(self.user.comment)
@@ -28,5 +31,3 @@ class TestFieldText(LoginTestCase):
     def test_field_text_write(self):
         # TODO
         pass
-
-# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:
