@@ -1,14 +1,12 @@
-# -*- coding: UTF-8 -*-
+# -*- coding: utf-8 -*-
 
 import tempfile
 
 from odoorpc.tests import LoginTestCase
-from odoorpc import error
 from odoorpc.tools import v
 
 
 class TestReport(LoginTestCase):
-
     def test_report_download_pdf(self):
         model = 'res.company'
         report_name = 'web.preview_internalreport'
@@ -20,7 +18,9 @@ class TestReport(LoginTestCase):
             file_.write(report.read())
 
     def test_report_download_qweb_pdf(self):
-        model = 'account.invoice'
+        model = 'account.move'
+        if v(self.odoo.version)[0] < 13:
+            model = 'account.invoice'
         report_name = 'account.report_invoice'
         ids = self.odoo.env[model].search([])[:10]
         report = self.odoo.report.download(report_name, ids)
@@ -29,15 +29,19 @@ class TestReport(LoginTestCase):
 
     def test_report_download_wrong_report_name(self):
         self.assertRaises(
-            ValueError,
-            self.odoo.report.download, 'wrong_report', [1])
+            ValueError, self.odoo.report.download, 'wrong_report', [1]
+        )
 
     def test_report_list(self):
         res = self.odoo.report.list()
         self.assertIsInstance(res, dict)
-        self.assertIn('account.invoice', res)
+        model = 'account.move'
+        if v(self.odoo.version)[0] < 13:
+            model = 'account.invoice'
+        self.assertIn(model, res)
         self.assertTrue(
-            any('account.report_invoice' in data['report_name']
-                for data in res['account.invoice']))
-
-# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:
+            any(
+                'account.report_invoice' in data['report_name']
+                for data in res[model]
+            )
+        )
