@@ -1,11 +1,10 @@
-# -*- coding: UTF-8 -*-
+# -*- coding: utf-8 -*-
 
-from odoorpc.tests import BaseTestCase
 from odoorpc import tools
+from odoorpc.tests import BaseTestCase
 
 
 class TestTools(BaseTestCase):
-
     def test_clean_version_numeric(self):
         version = tools.clean_version('6.1')
         self.assertEqual(version, '6.1')
@@ -23,9 +22,12 @@ class TestTools(BaseTestCase):
     def test_v_cmp(self):
         # [(v1, v2, is_inferior), ...]
         versions = [
-            ('7.0', '6.1', False), ('6.1', '7.0', True),
-            ('7.0alpha', '6.1', False), ('6.1beta', '7.0', True),
-            ('6.1beta', '5.0.16', False), ('5.0.16alpha', '6.1', True),
+            ('7.0', '6.1', False),
+            ('6.1', '7.0', True),
+            ('7.0alpha', '6.1', False),
+            ('6.1beta', '7.0', True),
+            ('6.1beta', '5.0.16', False),
+            ('5.0.16alpha', '6.1', True),
             ('8.0dev-20131102-000101', '7.0-20131014-231047', False),
         ]
         for v1, v2, is_inferior in versions:
@@ -34,5 +36,3 @@ class TestTools(BaseTestCase):
                 self.assertTrue(result)
             else:
                 self.assertFalse(result)
-
-# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:
