@@ -1,34 +1,23 @@
-# -*- coding: UTF-8 -*-
-##############################################################################
-#
-#    OdooRPC
-#    Copyright (C) 2014 Sébastien Alix.
-#
-#    This program is free software: you can redistribute it and/or modify
-#    it under the terms of the GNU Lesser General Public License as published
-#    by the Free Software Foundation, either version 3 of the License, or
-#    (at your option) any later version.
-#
-#    This program is distributed in the hope that it will be useful,
-#    but WITHOUT ANY WARRANTY; without even the implied warranty of
-#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#    GNU Lesser General Public License for more details.
-#
-#    You should have received a copy of the GNU Lesser General Public License
-#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#
-##############################################################################
+# -*- coding: utf-8 -*-
+# Copyright 2014 Sébastien Alix
+# License LGPL-3.0 or later (http://www.gnu.org/licenses/lgpl)
 """This module contains the :class:`Config <odoorpc.config.Config>` class which
-manage the configuration related to an instance of :class:`ODOO <odoorpc.ODOO>`,
-and some useful helper functions used internally in `OdooRPC`.
+manage the configuration related to an instance of
+:class:`ODOO <odoorpc.ODOO>`, and some useful helper functions used internally
+in `OdooRPC`.
 """
-import collections
+try:
+    from collections.abc import MutableMapping
+except ImportError:  # Python 2.7 compatibility
+    from collections import MutableMapping
 import re
 
+from .error import InternalError
+
 MATCH_VERSION = re.compile(r'[^\d.]')
 
 
-class Config(collections.MutableMapping):
+class Config(MutableMapping):
     """Class which manage the configuration of an
     :class:`ODOO <odoorpc.ODOO>` instance.
 
@@ -41,6 +30,7 @@ class Config(collections.MutableMapping):
     >>> type(odoo.config)
     <class 'odoorpc.tools.Config'>
     """
+
     def __init__(self, odoo, options):
         super(Config, self).__init__()
         self._odoo = odoo
@@ -126,11 +116,10 @@ def get_encodings(hint_encoding='utf-8'):
             yield charset
 
     from locale import getpreferredencoding
+
     prefenc = getpreferredencoding()
     if prefenc and prefenc.lower() != 'utf-8':
         yield prefenc
         prefenc = fallbacks.get(prefenc.lower())
         if prefenc:
             yield prefenc
-
-# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:
